note 123826 deleted from class.recursiveiteratoriterator by salathe
| From: | salathe@php.net | Date: | Mon, 24 Aug 2020 12:57:04 +0000 |
| Subject: | note 123826 deleted from class.recursiveiteratoriterator by salathe | ||
| References: | 1 | Groups: | php.notes |
| Request: | Send a blank email to php-notes+get-215015@lists.php.net to get a copy of this message | ||
Note Submitter: L00_Cyph3r
----
Some update on the speed of the previous benchmark from: https://www.php.net/manual/en/class.recursiveiteratoriterator.php#112713
This benchmark if run with PHP 7.3.3 running on a 6700k@4.4GHz on Linux 5.0.4-arch1-1-ARCH #1 SMP
PREEMPT
RecursiveIteratorIterator: 100 elements -> 0.006 sec
Recursive function : 100 elements -> 0.002 sec
RecursiveIteratorIterator: 1000 elements -> 0.035 sec
Recursive function : 1000 elements -> 0.013 sec
RecursiveIteratorIterator: 10000 elements -> 0.311 sec
Recursive function : 10000 elements -> 0.127 sec
RecursiveIteratorIterator: 100000 elements -> 3.130 sec
Recursive function : 100000 elements -> 1.302 sec
RecursiveIteratorIterator: 1000000 elements -> 31.223 sec
Recursive function : 1000000 elements -> 12.749 sec